=============
Release Notes
=============

See the :doc:`version numbers</topics/releases/version_numbers>` page for more
information about the version numbering scheme.

Latest Branch Release
=====================

|current_release_doc|

Previous Releases
=================

.. releasestree::
    :maxdepth: 1
    :glob:

    2016.3.*
    2015.8.*
    2015.5.*
    2014.7.*
    2014.1.*
    0.*

.. seealso:: :doc:`Legacy salt-cloud release docs <../cloud/releases/index>`

.. seealso:: :doc:`Legacy salt-api release docs <saltapi/index>`
